@@ -31,6 +31,7 @@
 #include <libgda/gda-blob-op.h>
 #include "../gda-sqlite.h"
 #include <sql-parser/gda-statement-struct-util.h>
+#include <libgda/gda-debug-macros.h>
 
 #define GDA_DEBUG_VIRTUAL
 #undef GDA_DEBUG_VIRTUAL
@@ -115,7 +116,7 @@ gda_vprovider_data_model_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		if (type == 0) {
 			static GTypeInfo info = {
 				sizeof (GdaVproviderDataModelClass),
@@ -129,10 +130,10 @@ gda_vprovider_data_model_get_type (void)
 				0
 			};
 			
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (GDA_TYPE_VIRTUAL_PROVIDER, "GdaVproviderDataModel", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 		}
 	}
 
@@ -248,6 +249,7 @@ virtual_filtered_data_new (VirtualTable *vtable, GdaDataModel *model,
 static void
 virtual_filtered_data_free (VirtualFilteredData *data)
 {
+	g_return_if_fail (data != NULL);
 	if (data->argv) {
 		int i;
 		for (i = 0; i < data->argc; i++)
@@ -278,6 +280,7 @@ virtual_filtered_data_free (VirtualFilteredData *data)
 static VirtualFilteredData *
 virtual_filtered_data_ref (VirtualFilteredData *data)
 {
+	g_return_if_fail (data != NULL);
 	data->refcount ++;
 	return data;
 }
@@ -285,6 +288,7 @@ virtual_filtered_data_ref (VirtualFilteredData *data)
 void
 _gda_vconnection_virtual_filtered_data_unref (VirtualFilteredData *data)
 {
+	g_return_if_fail (data != NULL);
 	data->refcount --;
 	if (data->refcount == 0)
 		virtual_filtered_data_free (data);
@@ -297,6 +301,7 @@ virtual_cursor_free (VirtualCursor *cursor)
 		return;
 
 	_gda_vconnection_virtual_filtered_data_unref (cursor->data);
+	cursor->data = NULL;
 	g_free (cursor);
 }
 
@@ -1291,7 +1296,6 @@ map_sqlite3_info_to_gda_filter (sqlite3_index_info *info, GdaVconnectionDataMode
 			if (! info->aConstraint[i].usable)
 				continue;
 
-			filter->aConstraint[j].iColumn = info->aConstraint[i].iColumn;
 			switch (info->aConstraint[i].op) {
 			case SQLITE_INDEX_CONSTRAINT_EQ:
 				filter->aConstraint[j].op = GDA_SQL_OPERATOR_TYPE_EQ;
@@ -1311,9 +1315,18 @@ map_sqlite3_info_to_gda_filter (sqlite3_index_info *info, GdaVconnectionDataMode
 			case SQLITE_INDEX_CONSTRAINT_MATCH:
 				filter->aConstraint[j].op = GDA_SQL_OPERATOR_TYPE_REGEXP;
 				break;
+#if HAVE_SQLITE
+			case SQLITE_INDEX_CONSTRAINT_LIKE:
+				filter->aConstraint[j].op = GDA_SQL_OPERATOR_TYPE_LIKE;
+				break;
+			case SQLITE_INDEX_CONSTRAINT_GLOB:
+				filter->aConstraint[j].op = GDA_SQL_OPERATOR_TYPE_GLOB;
+				break;
+#endif
 			default:
 				g_assert_not_reached ();
 			}
+			filter->aConstraint[j].iColumn = info->aConstraint[i].iColumn;
 
 			filter->aConstraintUsage[j].argvIndex = 0;
 			filter->aConstraintUsage[j].omit = FALSE;
